What is Chiplotle? — Chiplotle v0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.1 documentation »

# What is Chiplotle?

Chiplotle is a Python library that implements and extends the HPGL (Hewlett-Packard Graphics Language) plotter control language. It supports all the standard HPGL commands as well as more complex “compound HPGL” commands. Chiplotle also provides direct control of your HPGL-aware hardware via a standard usb<->serial port interface.

Chiplotle is written and maintained by Víctor Adán and Douglas Repetto.

Find all there is to know about Chiplotle at: http://www.chiplotle.org

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.1 documentation »